@@ -213,12 +213,12 @@ static Mb5Metadata
 query_musicbrainz (SjMetadataMusicbrainz5  *self,
                    const char              *entity,
                    const char              *id,
-                   char                    *includes,
+                   const char              *includes,
                    GCancellable            *cancellable,
                    GError                 **error)
 {
   Mb5Metadata metadata;
-  char *inc[] = { "inc" };
+  char *inc, *includes_copy;
   gint64 delay = 4 * G_USEC_PER_SEC;
   int count = 0;
   SjMetadataMusicbrainz5Private *priv = GET_PRIVATE (self);
@@ -226,6 +226,9 @@ query_musicbrainz (SjMetadataMusicbrainz5  *self,
 
   g_info ("Querying %s %s", entity, id);
 
+  inc = g_strdup ("inc");
+  includes_copy = g_strdup (includes);
+
   while (TRUE) {
     if (g_cancellable_set_error_if_cancelled (cancellable, error))
       return NULL;
@@ -241,7 +244,7 @@ query_musicbrainz (SjMetadataMusicbrainz5  *self,
                                   0, NULL, NULL);
     else
       metadata = mb5_query_query (priv->mb, entity, id, "",
-                                  1, inc, &includes);
+                                  1, &inc, &includes_copy);
 
     if (metadata != NULL || ++count == 5 ||
         mb5_query_get_lasthttpcode (priv->mb) != 503)
@@ -261,6 +264,8 @@ query_musicbrainz (SjMetadataMusicbrainz5  *self,
     print_musicbrainz_query_error (self, entity, id);
 
   last_query_time = g_get_monotonic_time ();
+  g_free (inc);
+  g_free (includes_copy);
   return metadata;
 }
 
@@ -310,13 +315,15 @@ static gboolean
 mcn_matches_barcode (const char *mcn,
                      const char *barcode)
 {
+  gsize len;
+
   if (mcn == NULL || barcode == NULL)
     return FALSE;
 
   /* The MCN should match an EAN barcode (13 digits)
    * or an UPC barcode (12 digits) with a leading '0'.
    */
-  gsize len = strlen (barcode);
+  len = strlen (barcode);
   if (len == 12) /* UPC barcode - skip leading '0' */
     return *mcn == '0' && strcmp (mcn + 1, barcode) == 0;
   else if (len == 13) /* EAN barcode */
@@ -415,7 +422,7 @@ get_artist_list (SjMetadataMusicbrainz5 *self,
 {
   Mb5NameCreditList name_list;
   GList *artists;
-  unsigned int i;
+  int i;
   char buffer[512]; /* for the GET macro */
 
   if (credit == NULL)
@@ -574,7 +581,7 @@ static void relationlist_list_foreach_relation(SjMetadataMusicbrainz5 *self,
                                                RelationForeachFunc     callback,
                                                gpointer                user_data)
 {
-  unsigned int j;
+  int j;
 
   if (relation_lists == NULL)
     return;
@@ -582,7 +589,7 @@ static void relationlist_list_foreach_relation(SjMetadataMusicbrainz5 *self,
   for (j = 0; j < mb5_relationlist_list_size (relation_lists); j++) {
     Mb5RelationList relations;
     char type[512]; /* To hold relationlist target-type and relation type */
-    unsigned int i;
+    int i;
 
     relations = mb5_relationlist_list_item (relation_lists, j);
     if (relations == NULL)
@@ -872,7 +879,7 @@ fill_tracks_from_medium (SjMetadataMusicbrainz5  *self,
 {
   Mb5TrackList track_list;
   GList *tracks;
-  unsigned int i;
+  int i;
   gboolean skip_data_tracks;
   char buffer[512]; /* for the GET() macro */
 
@@ -891,7 +898,7 @@ fill_tracks_from_medium (SjMetadataMusicbrainz5  *self,
     Mb5Recording recording;
     TrackDetails *track;
     gchar *title;
-    gint track_offset;
+    gint track_offset = 0;
 
     mbt = mb5_track_list_item (track_list, i);
     if (!mbt)
@@ -1124,7 +1131,7 @@ mb5_list_albums (SjMetadata    *metadata,
     AlbumDetails *album;
     Mb5Release full_release = NULL;
     Mb5Metadata release_md = NULL;
-    char *includes = "aliases artists artist-credits labels recordings \
+    const char *release_includes = "aliases artists artist-credits labels recordings \
 release-groups url-rels discids recording-level-rels work-level-rels work-rels \
 artist-rels";
 
@@ -1132,7 +1139,7 @@ artist-rels";
      * In order to get metadata for artist aliases & work / composer
      * relationships we need to perform a custom query
      */
-    release_md = query_musicbrainz (self, "release", disc->release_ids[i], includes, cancellable, error);
+    release_md = query_musicbrainz (self, "release", disc->release_ids[i], release_includes, cancellable, error);
     if (*error != NULL)
       goto free_releases;
 
@@ -1152,10 +1159,10 @@ artist-rels";
          * release-group, so run a separate query to get these urls
          */
         char *releasegroupid = NULL;
-        char *includes = "artists url-rels";
+        const char *group_includes = "artists url-rels";
 
         GET (releasegroupid, mb5_releasegroup_get_id, group);
-        group_md = query_musicbrainz (self, "release-group", releasegroupid, includes, cancellable, error);
+        group_md = query_musicbrainz (self, "release-group", releasegroupid, group_includes, cancellable, error);
         g_free (releasegroupid);
         if (*error != NULL) {
           mb5_metadata_delete (release_md);
