@@ -362,13 +362,13 @@ char *
 sj_metadata_helper_lookup_country_code (const char *code)
 {
   const char *country_name;
-  int len, i;
+  gsize len, i;
   /* Musicbrainz uses some additional codes on top of ISO-3166 so
      treat those as a special case if we don't get a match from the
      iso-codes data */
-  const static struct {
-    char *code;
-    char *name;
+  static const struct {
+    const char *code;
+    const char *name;
   } mb_countries[]  = {
     {"XC", N_("Czechoslovakia")},
     {"XG", N_("East Germany")},
