@@ -31,6 +31,7 @@
 #include <gst/gst.h>
 
 #include "egg-play-preview.h"
+#include "sj-util.h"
 
 enum {
 	PROP_NONE,
@@ -83,8 +84,6 @@ struct _EggPlayPreviewPrivate {
 	gchar *uri;
 };
 
-static void	egg_play_preview_class_init   (EggPlayPreviewClass *klass);
-static void	egg_play_preview_init         (EggPlayPreview      *play_preview);
 static void egg_play_preview_finalize     (GObject             *object);
 static void egg_play_preview_dispose      (GObject             *object);
 static void	egg_play_preview_set_property (GObject             *object,
@@ -712,6 +711,7 @@ _process_bus_messages (GstBus *bus, GstMessage *msg, EggPlayPreview *play_previe
 
 	priv = GET_PRIVATE (play_preview);
 
+        SJ_BEGIN_IGNORE_SWITCH_ENUM
 	switch (GST_MESSAGE_TYPE (msg)) {
 	case GST_MESSAGE_DURATION_CHANGED:
 		if (!gst_element_query_duration (priv->playbin, GST_FORMAT_TIME, &duration))
@@ -789,6 +789,7 @@ _process_bus_messages (GstBus *bus, GstMessage *msg, EggPlayPreview *play_previe
 	default:
 		break;
 	}
+        SJ_END_IGNORE_SWITCH_ENUM
 
 	return TRUE;
 }
