@@ -49,7 +49,6 @@
 #include "sj-structures.h"
 #include "sj-error.h"
 #include "sj-util.h"
-#include "sj-main.h"
 #include "sj-prefs.h"
 #include "sj-play.h"
 #include "sj-genres.h"
@@ -65,6 +64,7 @@ static void set_action_state (const char *detailed_name);
 /* Prototypes for the signal blocking/unblocking in update_ui_for_album */
 G_MODULE_EXPORT void on_title_edit_changed(GtkEditable *widget, gpointer user_data);
 G_MODULE_EXPORT void on_person_edit_changed(GtkEditable *widget, gpointer user_data);
+G_MODULE_EXPORT void on_genre_edit_changed(GtkEditable *widget, gpointer user_data);
 G_MODULE_EXPORT void on_year_edit_changed(GtkEditable *widget, gpointer user_data);
 G_MODULE_EXPORT void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data);
 G_MODULE_EXPORT void submit_bar_response_cb (GtkInfoBar *infobar, int response_id, gpointer user_data);
@@ -73,23 +73,23 @@ G_MODULE_EXPORT void on_activate_move_focus (GtkWidget *widget, gpointer data);
 GtkBuilder *builder;
 
 SjMetadataGetter *metadata;
-SjExtractor *extractor;
+SjExtractor *sj_extractor;
 
 GSettings *sj_settings;
 
 GtkWidget *main_window;
 static GtkWidget *submit_bar, *submit_label;
 static GtkWidget *title_entry, *artist_entry, *composer_label, *composer_entry, *duration_label, *genre_entry, *year_entry, *disc_number_entry;
-static GtkWidget *entry_table; /* GtkTable containing composer_entry */
+static GtkWidget *entry_grid; /* GtkGrid containing album title, artist etc. */
 static GtkTreeViewColumn *composer_column; /* Treeview column containing composers */
 static GtkWidget *track_listview, *extract_button, *play_button, *select_button;
 static GtkWidget *multiple_album_dialog, *status_bar, *submit_button, *reload_button;
 GtkListStore *track_store;
 GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer, *composer_renderer;
 
-char *path_pattern, *file_pattern;
-GFile *base_uri;
-BraseroDrive *drive = NULL;
+char *sj_path_pattern, *sj_file_pattern;
+GFile *sj_base_uri;
+BraseroDrive *sj_drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
 gboolean open_finished;
@@ -104,7 +104,7 @@ static char *current_submit_url = NULL;
 static GCancellable *reread_cancellable; /* weak reference */
 
 gboolean autostart = FALSE, autoplay = FALSE;
-static char *device = NULL, **uris = NULL;
+static char *sj_device = NULL, **uris = NULL;
 
 static guint debug_flags = 0;
 
@@ -121,7 +121,6 @@ static CellCbContext cell_editing_context;
 
 #define DEFAULT_PARANOIA 15
 #define RAISE_WINDOW "raise-window"
-#define COMPOSER_ROW 2 /* Row of entry_table containing composer_entry */
 
 void
 sj_main_set_title (const char* detail)
@@ -219,7 +218,7 @@ static void on_eject_activate (GSimpleAction *action, GVariant *parameter, gpoin
 {
   disc_ejected_cb ();
   eject_activated = TRUE;
-  brasero_drive_eject (drive, FALSE, NULL);
+  brasero_drive_eject (sj_drive, FALSE, NULL);
 }
 
 G_MODULE_EXPORT gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -443,7 +442,7 @@ static void on_duplicate_activate (GSimpleAction *action, GVariant *parameter, g
   GError *error = NULL;
   const gchar* device;
 
-  device = brasero_drive_get_device (drive);
+  device = brasero_drive_get_device (sj_drive);
   if (!g_spawn_command_line_async (g_strconcat ("brasero -c ", device, NULL), &error)) {
       GtkWidget *dialog;
 
@@ -462,7 +461,6 @@ static void on_duplicate_activate (GSimpleAction *action, GVariant *parameter, g
   }
 }
 
-#define TABLE_ROW_SPACING 6 /* spacing of rows in entry_table */
 
 /*
  * Show composer entry and composer column in track listview
@@ -471,8 +469,6 @@ static void
 show_composer_fields (void)
 {
   if (!gtk_widget_get_visible (GTK_WIDGET (composer_label))) {
-    gtk_table_set_row_spacing (GTK_TABLE (entry_table), COMPOSER_ROW,
-                               TABLE_ROW_SPACING);
     gtk_widget_show (GTK_WIDGET (composer_entry));
     gtk_widget_show (GTK_WIDGET (composer_label));
     gtk_tree_view_column_set_visible (composer_column, TRUE);
@@ -488,7 +484,6 @@ static void
 hide_composer_fields (void)
 {
   if (gtk_widget_get_visible (GTK_WIDGET (composer_label))) {
-    gtk_table_set_row_spacing (GTK_TABLE (entry_table), COMPOSER_ROW, 0);
     gtk_widget_hide (GTK_WIDGET (composer_entry));
     gtk_widget_hide (GTK_WIDGET (composer_label));
     gtk_tree_view_column_set_visible (composer_column, FALSE);
@@ -502,14 +497,14 @@ hide_composer_fields (void)
 static void
 composer_show_hide (const char* genre)
 {
-  const static char *composer_genres[] = {
+  static const char *composer_genres[] = {
     N_("Classical"), N_("Lieder"), N_("Opera"), N_("Chamber"), N_("Musical")
   };  /* Genres for which the composer fields should be shown. */
 #define COUNT (G_N_ELEMENTS (composer_genres))
   static char *genres[COUNT]; /* store localized genre names */
   static gboolean init = FALSE; /* TRUE if localized genre names initalized*/
   gboolean composer_show = FALSE;
-  int i;
+  gsize i;
   GList* l;
   char *folded_genre;
 
@@ -525,7 +520,7 @@ composer_show_hide (const char* genre)
 
   composer_show = !sj_str_is_empty (current_album->composer);
   for (l = current_album->tracks; l; l = g_list_next (l)) {
-    if (!sj_str_is_empty (((TrackDetails*) (l->data))->composer) == TRUE) {
+    if (!sj_str_is_empty (((TrackDetails*) (l->data))->composer)) {
       composer_show = TRUE;
       break;
     }
@@ -698,23 +693,23 @@ choose_album(GList *albums)
 /**
  * The GSettings key for the base path changed
  */
-static void baseuri_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void baseuri_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   gchar *value;
   g_assert (strcmp (key, SJ_SETTINGS_BASEURI) == 0);
-  if (base_uri) {
-    g_object_unref (base_uri);
+  if (sj_base_uri) {
+    g_object_unref (sj_base_uri);
   }
   value = g_settings_get_string (settings, key);
   if (sj_str_is_empty (value)) {
-    base_uri = sj_get_default_music_directory ();
+    sj_base_uri = sj_get_default_music_directory ();
   } else {
     GFileType file_type;
-    base_uri = g_file_new_for_uri (value);
-    file_type = g_file_query_file_type (base_uri, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL);
+    sj_base_uri = g_file_new_for_uri (value);
+    file_type = g_file_query_file_type (sj_base_uri, G_FILE_QUERY_INFO_NONE, NULL);
     if (file_type != G_FILE_TYPE_DIRECTORY) {
-      g_object_unref (base_uri);
-      base_uri = sj_get_default_music_directory ();
+      g_object_unref (sj_base_uri);
+      sj_base_uri = sj_get_default_music_directory ();
     }
   }
   g_free (value);
@@ -723,14 +718,14 @@ static void baseuri_changed_cb (GSettings *settings, gchar *key, gpointer user_d
 /**
  * The GSettings key for the directory pattern changed
  */
-static void path_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void path_pattern_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   g_assert (strcmp (key, SJ_SETTINGS_PATH_PATTERN) == 0);
-  g_free (path_pattern);
-  path_pattern = g_settings_get_string (settings, key);
-  if (sj_str_is_empty (path_pattern)) {
-    g_free (path_pattern);
-    path_pattern = g_strdup (sj_get_default_path_pattern ());
+  g_free (sj_path_pattern);
+  sj_path_pattern = g_settings_get_string (settings, key);
+  if (sj_str_is_empty (sj_path_pattern)) {
+    g_free (sj_path_pattern);
+    sj_path_pattern = g_strdup (sj_get_default_path_pattern ());
   }
   /* TODO: sanity check the pattern */
 }
@@ -738,14 +733,14 @@ static void path_pattern_changed_cb (GSettings *settings, gchar *key, gpointer u
 /**
  * The GSettings key for the filename pattern changed
  */
-static void file_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void file_pattern_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   g_assert (strcmp (key, SJ_SETTINGS_FILE_PATTERN) == 0);
-  g_free (file_pattern);
-  file_pattern = g_settings_get_string (settings, key);
-  if (sj_str_is_empty (file_pattern)) {
-    g_free (file_pattern);
-    file_pattern = g_strdup (sj_get_default_file_pattern ());
+  g_free (sj_file_pattern);
+  sj_file_pattern = g_settings_get_string (settings, key);
+  if (sj_str_is_empty (sj_file_pattern)) {
+    g_free (sj_file_pattern);
+    sj_file_pattern = g_strdup (sj_get_default_file_pattern ());
   }
   /* TODO: sanity check the pattern */
 }
@@ -753,16 +748,16 @@ static void file_pattern_changed_cb (GSettings *settings, gchar *key, gpointer u
 /**
  * The GSettings key for the paranoia mode has changed
  */
-static void paranoia_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void paranoia_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   int value;
   g_assert (strcmp (key, SJ_SETTINGS_PARANOIA) == 0);
   value = g_settings_get_flags (settings, key);
   if (value >= 0) {
     if (value < 32) {
-      sj_extractor_set_paranoia (extractor, value);
+      sj_extractor_set_paranoia (sj_extractor, value);
     } else {
-      sj_extractor_set_paranoia (extractor, DEFAULT_PARANOIA);
+      sj_extractor_set_paranoia (sj_extractor, DEFAULT_PARANOIA);
     }
   }
 }
@@ -770,7 +765,7 @@ static void paranoia_changed_cb (GSettings *settings, gchar *key, gpointer user_
 /**
  * The GSettings key for the strip characters option changed
  */
-static void strip_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void strip_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   g_assert (strcmp (key, SJ_SETTINGS_STRIP) == 0);
   strip_chars = g_settings_get_boolean (settings, key);
@@ -779,7 +774,7 @@ static void strip_changed_cb (GSettings *settings, gchar *key, gpointer user_dat
 /**
  * The GSettings key for the eject when finished option changed
  */
-static void eject_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void eject_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   g_assert (strcmp (key, SJ_SETTINGS_EJECT) == 0);
   eject_finished = g_settings_get_boolean (settings, key);
@@ -788,7 +783,7 @@ static void eject_changed_cb (GSettings *settings, gchar *key, gpointer user_dat
 /**
  * The GSettings key for the open when finished option changed
  */
-static void open_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void open_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   g_assert (strcmp (key, SJ_SETTINGS_OPEN) == 0);
   open_finished = g_settings_get_boolean (settings, key);
@@ -797,11 +792,13 @@ static void open_changed_cb (GSettings *settings, gchar *key, gpointer user_data
 /**
  * The GSettings key for audio volume changes
  */
-static void audio_volume_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void audio_volume_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
+  GtkWidget *volb;
+
   g_assert (strcmp (key, SJ_SETTINGS_AUDIO_VOLUME) == 0);
 
-  GtkWidget *volb = GET_WIDGET ("volume_button");
+  volb = GET_WIDGET ("volume_button");
   gtk_scale_button_set_value (GTK_SCALE_BUTTON (volb), g_settings_get_double (settings, key));
 }
 
@@ -914,14 +911,14 @@ static void reread_cd (void)
   /* Make sure nothing is playing */
   stop_playback ();
 
-  if (!drive)
+  if (!sj_drive)
     sj_debug (DEBUG_CD, "Attempting to re-read NULL drive\n");
 
   g_free (current_submit_url);
   current_submit_url = NULL;
   set_action_enabled ("submit-tracks", FALSE);
 
-  if (!is_audio_cd (drive)) {
+  if (!is_audio_cd (sj_drive)) {
     sj_debug (DEBUG_CD, "Media is not an audio CD\n");
     set_action_state ("re-read(false)");
     update_ui_for_album (NULL);
@@ -977,17 +974,17 @@ set_drive_from_device (const char *device)
 {
   BraseroMediumMonitor *monitor;
 
-  if (drive) {
-    g_object_unref (drive);
-    drive = NULL;
+  if (sj_drive) {
+    g_object_unref (sj_drive);
+    sj_drive = NULL;
   }
 
   if (! device)
     return;
 
   monitor = brasero_medium_monitor_get_default ();
-  drive = brasero_medium_monitor_get_drive (monitor, device);
-  if (! drive) {
+  sj_drive = brasero_medium_monitor_get_drive (monitor, device);
+  if (!sj_drive) {
     GtkWidget *dialog;
     char *message;
     message = g_strdup_printf (_("Sound Juicer could not use the CD-ROM device ‘%s’"), device);
@@ -1044,16 +1041,16 @@ set_device (const char* device)
   }
 
   sj_metadata_getter_set_cdrom (metadata, device);
-  sj_extractor_set_device (extractor, device);
+  sj_extractor_set_device (sj_extractor, device);
 
-  if (drive != NULL) {
-    tray_opened = brasero_drive_is_door_open (drive);
+  if (sj_drive != NULL) {
+    tray_opened = brasero_drive_is_door_open (sj_drive);
     if (tray_opened == FALSE) {
       reread_cd ();
     }
 
     /* Enable/disable the eject options based on wether the drive supports ejection */
-    set_action_enabled ("eject", brasero_drive_can_eject (drive));
+    set_action_enabled ("eject", brasero_drive_can_eject (sj_drive));
   }
 }
 
@@ -1102,7 +1099,7 @@ prefs_get_default_device (void)
 /**
  * The GSettings key for the device changed
  */
-static void device_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void device_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   const char *device;
   char *value;
@@ -1133,7 +1130,7 @@ static void device_changed_cb (GSettings *settings, gchar *key, gpointer user_da
   g_free (value);
 }
 
-static void profile_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void profile_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   GstEncodingProfile *profile;
   char *media_type;
@@ -1143,7 +1140,7 @@ static void profile_changed_cb (GSettings *settings, gchar *key, gpointer user_d
   profile = rb_gst_get_encoding_profile (media_type);
   g_free (media_type);
   if (profile != NULL)
-    g_object_set (extractor, "profile", profile, NULL);
+    g_object_set (sj_extractor, "profile", profile, NULL);
 
   if (profile == NULL || !sj_extractor_supports_profile(profile)) {
     GtkWidget *dialog;
@@ -1334,6 +1331,7 @@ on_cell_editing_done_foreach (GtkTreeModel *model,
   gtk_tree_model_get (GTK_TREE_MODEL (track_store), iter,
                       COLUMN_DETAILS, &track,
                       -1);
+  SJ_BEGIN_IGNORE_SWITCH_ENUM
   switch (context->column) {
   case COLUMN_TITLE:
     g_free (track->title);
@@ -1363,6 +1361,7 @@ on_cell_editing_done_foreach (GtkTreeModel *model,
     g_warning ("Unknown column %d in on_cell_editing_done_foreach",
                context->column);
   }
+  SJ_END_IGNORE_SWITCH_ENUM
 }
 
 static void
@@ -1378,6 +1377,7 @@ on_cell_editing_canceled_foreach (GtkTreeModel *model,
   /* COLUMN_DETAILS isn't updated during editing so get original
      values back from it. */
   gtk_tree_model_get (model, iter, COLUMN_DETAILS, &track, -1);
+  SJ_BEGIN_IGNORE_SWITCH_ENUM
   switch (context->column) {
   case COLUMN_TITLE:
     text = track->title;
@@ -1393,6 +1393,7 @@ on_cell_editing_canceled_foreach (GtkTreeModel *model,
                context->column);
     return;
   }
+ SJ_END_IGNORE_SWITCH_ENUM
   gtk_list_store_set (track_store, iter, context->column, text, -1);
 }
 
@@ -1662,25 +1663,25 @@ static void on_contents_activate(GSimpleAction *action, GVariant *parameter, gpo
 static gboolean
 is_cd_duplication_available(void)
 {
+  gchar *brasero_cd_burner, *cdrdao;
+  BraseroMediumMonitor *monitor;
+  GSList *drives, *iter;
+
   /* First check the brasero tool is available in the path */
-  gchar* brasero_cd_burner = g_find_program_in_path ("brasero");
+  brasero_cd_burner = g_find_program_in_path ("brasero");
   if (brasero_cd_burner == NULL) {
     return FALSE;
   }
   g_free(brasero_cd_burner);
 
   /* Second check the cdrdao tool is available in the path */
-  gchar* cdrdao = g_find_program_in_path ("cdrdao");
+  cdrdao = g_find_program_in_path ("cdrdao");
   if (cdrdao == NULL) {
     return FALSE;
   }
   g_free(cdrdao);
 
   /* Now check that there is at least one cd recorder available */
-  BraseroMediumMonitor     *monitor;
-  GSList		   *drives;
-  GSList		   *iter;
-
   monitor = brasero_medium_monitor_get_default ();
   drives = brasero_medium_monitor_get_drives (monitor, BRASERO_DRIVE_TYPE_ALL);
 
@@ -1767,12 +1768,32 @@ add_editable_listview_column (const char       *title,
   return renderer;
 }
 
+/*
+ * Action accelerator definitions. For each action the first entry is
+ * the detailed name of the action followed by up to 3 accelerators
+ * followed by NULL.
+ */
+static const gchar *action_accels[][5] = {
+  { "win.play", "<Primary>p", NULL },
+  { "win.next-track", "<Primary>n", NULL },
+  { "win.previous-track", "<Primary>b", NULL},
+  { "win.select-all", "<Primary>a", NULL},
+  { "win.deselect-all", "<Primary><Shift>a", NULL}
+};
+
 static void
 startup_cb (GApplication *app, gpointer user_data)
 {
+  gsize i;
   GtkTreeSelection *selection;
   GError *error = NULL;
 
+  g_setenv ("PULSE_PROP_media.role", "music", TRUE);
+
+  sj_debug_init ();
+
+  gtk_window_set_default_icon_name ("sound-juicer");
+
   brasero_media_library_start ();
 
   metadata = sj_metadata_getter_new ();
@@ -1830,7 +1851,7 @@ startup_cb (GApplication *app, gpointer user_data)
   play_button           = GET_WIDGET ("play_button");
   select_button         = GET_WIDGET ("select_button");
   status_bar            = GET_WIDGET ("status_bar");
-  entry_table           = GET_WIDGET ("entry_table");
+  entry_grid            = GET_WIDGET ("entry_grid");
 
   sj_main_window_init (GTK_WINDOW (main_window));
 
@@ -1846,16 +1867,10 @@ startup_cb (GApplication *app, gpointer user_data)
   gtk_actionable_set_action_name(GTK_ACTIONABLE(play_button), "win.play");
 
   /* window actions are only available via shortcuts */
-  gtk_application_add_accelerator (GTK_APPLICATION (app),
-                                   "<Primary>p", "win.play", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (app),
-                                   "<Primary>n", "win.next-track", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (app),
-                                   "<Primary>b", "win.previous-track", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (app),
-                                   "<Primary>a", "win.select-all", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (app),
-                                   "<Primary><Shift>a", "win.deselect-all", NULL);
+  for (i = 0; i < G_N_ELEMENTS (action_accels); i++)
+    gtk_application_set_accels_for_action (GTK_APPLICATION (app),
+                                           action_accels[i][0],
+                                           &action_accels[i][1]);
 
   { /* ensure that the play/pause button's size is constant */
     GtkWidget *fake_button1, *fake_button2;
@@ -1929,9 +1944,6 @@ startup_cb (GApplication *app, gpointer user_data)
 
   setup_genre_entry (genre_entry);
 
-  /* Remove row spacing from hidden row containing composer_entry */
-  gtk_table_set_row_spacing (GTK_TABLE (entry_table), COMPOSER_ROW, 0);
-
   track_store = gtk_list_store_new (COLUMN_TOTAL, G_TYPE_INT, G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
   gtk_tree_view_set_model (GTK_TREE_VIEW (track_listview), GTK_TREE_MODEL (track_store));
   {
@@ -1976,8 +1988,8 @@ startup_cb (GApplication *app, gpointer user_data)
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
   }
 
-  extractor = SJ_EXTRACTOR (sj_extractor_new());
-  error = sj_extractor_get_new_error (extractor);
+  sj_extractor = SJ_EXTRACTOR (sj_extractor_new());
+  error = sj_extractor_get_new_error (sj_extractor);
   if (error) {
     error_on_start (error);
     exit (1);
@@ -1999,15 +2011,15 @@ startup_cb (GApplication *app, gpointer user_data)
   eject_changed_cb (sj_settings, SJ_SETTINGS_EJECT, NULL);
   open_changed_cb (sj_settings, SJ_SETTINGS_OPEN, NULL);
   audio_volume_changed_cb (sj_settings, SJ_SETTINGS_AUDIO_VOLUME, NULL);
-  if (device == NULL && uris == NULL) {
+  if (sj_device == NULL && uris == NULL) {
     /* FIXME: this should set the device gsettings key to a meaningful
      * value if it's empty (which is the case until the user changes it in
      * the prefs)
      */
     device_changed_cb (sj_settings, SJ_SETTINGS_DEVICE, NULL);
   } else {
-    if (device)
-      set_device (device);
+    if (sj_device)
+      set_device (sj_device);
     else {
       char *d;
 
@@ -2040,6 +2052,17 @@ startup_cb (GApplication *app, gpointer user_data)
   gtk_widget_show (main_window);
 }
 
+static void
+shutdown_cb (GApplication *app, gpointer user_data)
+{
+  sj_metadata_helper_cleanup ();
+  g_object_unref (sj_base_uri);
+  g_object_unref (metadata);
+  g_object_unref (sj_extractor);
+  g_object_unref (sj_settings);
+  brasero_media_library_stop ();
+}
+
 static void
 activate_cb (GApplication *app, gpointer user_data)
 {
@@ -2112,13 +2135,11 @@ void set_action_enabled (const char *name, gboolean enabled)
 
 int main (int argc, char **argv)
 {
-  GError *error = NULL;
   GtkApplication *app;
-  GOptionContext *ctx;
   const GOptionEntry entries[] = {
     { "auto-start", 'a', 0, G_OPTION_ARG_NONE, &autostart, N_("Start extracting immediately"), NULL },
     { "play", 'p', 0, G_OPTION_ARG_NONE, &autoplay, N_("Start playing immediately"), NULL},
-    { "device", 'd', 0, G_OPTION_ARG_FILENAME, &device, N_("What CD device to read"), N_("DEVICE") },
+    { "device", 'd', 0, G_OPTION_ARG_FILENAME, &sj_device, N_("What CD device to read"), N_("DEVICE") },
     { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &uris, N_("URI to the CD device to read"), NULL },
     { NULL }
   };
@@ -2129,44 +2150,22 @@ int main (int argc, char **argv)
   textdomain (PACKAGE);
 
   g_set_application_name (_("Sound Juicer"));
-  g_setenv ("PULSE_PROP_media.role", "music", TRUE);
 
-  ctx = g_option_context_new (N_("- Extract music from your CDs"));
-  g_option_context_add_main_entries (ctx, entries, PACKAGE);
-  g_option_context_set_translation_domain(ctx, PACKAGE);
-  g_option_context_add_group (ctx, gtk_get_option_group (TRUE));
-  g_option_context_add_group (ctx, gst_init_get_option_group ());
-  g_option_context_add_group (ctx, brasero_media_get_option_group ());
-  g_option_context_set_ignore_unknown_options (ctx, TRUE);
-
-  g_option_context_parse (ctx, &argc, &argv, &error);
-  if (error != NULL) {
-      g_printerr ("Error parsing options: %s", error->message);
-      exit (1);
-  }
-  g_option_context_free (ctx);
-
-  sj_debug_init ();
-
-  gtk_window_set_default_icon_name ("sound-juicer");
-
-  app = gtk_application_new ("org.gnome.sound-juicer",
+  app = gtk_application_new ("org.gnome.SoundJuicer",
                              G_APPLICATION_FLAGS_NONE);
+  g_application_set_resource_base_path (G_APPLICATION (app), "/org/gnome/sound-juicer");
+  g_application_add_main_option_entries (G_APPLICATION (app), entries);
+  g_application_add_option_group (G_APPLICATION (app), gst_init_get_option_group ());
+  g_application_add_option_group (G_APPLICATION (app), brasero_media_get_option_group ());
 
   g_object_set (app, "register-session", TRUE, NULL);
   g_signal_connect (app, "startup", G_CALLBACK (startup_cb), NULL);
+  g_signal_connect (app, "shutdown", G_CALLBACK (shutdown_cb), NULL);
   g_signal_connect (app, "activate", G_CALLBACK (activate_cb), NULL);
 
   status = g_application_run (G_APPLICATION (app), argc, argv);
 
   g_object_unref (app);
 
-  sj_metadata_helper_cleanup ();
-  g_object_unref (base_uri);
-  g_object_unref (metadata);
-  g_object_unref (extractor);
-  g_object_unref (sj_settings);
-  brasero_media_library_stop ();
-
   return status;
 }
