@@ -35,16 +35,13 @@
 #include "sj-extracting.h"
 #include "sj-prefs.h"
 
-extern GtkBuilder *builder;
-extern GtkWidget *main_window;
-
 static GtkWidget *profile_option;
 static GtkWidget *cd_option, *path_option, *file_option, *basepath_fcb, *check_strip, *check_eject, *check_open;
 static GtkWidget *path_example_label;
 
 typedef struct {
-  char* name;
-  char* pattern;
+  const char* name;
+  const char* pattern;
 } FilePattern;
 
 static const FilePattern path_patterns[] = {
@@ -156,7 +153,7 @@ static void prefs_pattern_option_changed (GtkComboBox *combo, gpointer key)
   }
 }
 
-static void baseuri_changed_cb  (GSettings *settings, gchar *key, gpointer user_data)
+static void baseuri_changed_cb  (GSettings *settings, const gchar *key, gpointer user_data)
 {
   /*
    * The conflict between separation of the prefs and the main window,
@@ -194,6 +191,10 @@ static void pattern_label_update (void)
   char *media_type;
   GstEncodingProfile *profile;
 
+  /* Disable -Wdiscarded-quantifiers to prevent warnings as we're
+     initalizing gchar* from const gchar*. This is safe as the strings
+     are never changed. */
+SJ_BEGIN_IGNORE_DISCARDED_QUANTIFIERS
   static const AlbumDetails sample_album = {
     .title = "Help!", /* title */
     .artist = "The Beatles", /* artist */
@@ -218,8 +219,9 @@ static void pattern_label_update (void)
     .track_id = NULL, /* track ID */
     .artist_id = NULL, /* artist ID */
   };
+SJ_END_IGNORE_DISCARDED_QUANTIFIERS
 
-  g_object_get (extractor, "profile", &profile, NULL);
+  g_object_get (sj_extractor, "profile", &profile, NULL);
   /* It's possible the profile isn't set, in which case do nothing */
   if (!profile) {
     return;
@@ -260,7 +262,7 @@ static void pattern_label_update (void)
   g_free (format);
 }
 
-static void settings_changed_cb (GSettings *settings, gchar *key, gpointer combo)
+static void settings_changed_cb (GSettings *settings, const gchar *key, gpointer combo)
 {
   char *value;
 
@@ -275,7 +277,7 @@ static void settings_changed_cb (GSettings *settings, gchar *key, gpointer combo
 /**
  * Default device changed (either GSettings key or the widget)
  */
-static void device_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void device_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   BraseroDrive *drive;
   BraseroMediumMonitor *monitor;
@@ -310,7 +312,7 @@ static void prefs_drive_changed (BraseroDriveSelection *selection, BraseroDrive
 /**
  * The GSettings key for the strip characters option changed
  */
-static void strip_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void strip_changed_cb (GSettings *settings, const gchar *key, gpointer user_data)
 {
   /* NOTE that strip_changed_cb in sj-main.c will also be called, and will also update
      the global value strip_chars - but which function will get called first?
@@ -371,15 +373,15 @@ static void populate_profile_combo (GtkComboBox *combo)
 /**
  * Clicked on Preferences in the UI
  */
-void show_preferences_dialog ()
+void show_preferences_dialog (void)
 {
   static GtkWidget *prefs_dialog = NULL;
 
   if (prefs_dialog) {
     gtk_window_present (GTK_WINDOW (prefs_dialog));
   } else {
-    static gchar *path_key = SJ_SETTINGS_PATH_PATTERN;
-    static gchar *file_key = SJ_SETTINGS_FILE_PATTERN;
+    static const gchar *path_key = SJ_SETTINGS_PATH_PATTERN;
+    static const gchar *file_key = SJ_SETTINGS_FILE_PATTERN;
 
     prefs_dialog = GET_WIDGET ("prefs_dialog");
     g_assert (prefs_dialog != NULL);
@@ -399,9 +401,19 @@ void show_preferences_dialog ()
 
     sj_add_default_dirs (GTK_FILE_CHOOSER (basepath_fcb));
     populate_pattern_combo (GTK_COMBO_BOX (path_option), path_patterns);
-    g_signal_connect (path_option, "changed", G_CALLBACK (prefs_pattern_option_changed), path_key);
-    populate_pattern_combo (GTK_COMBO_BOX (file_option), file_patterns);
-    g_signal_connect (file_option, "changed", G_CALLBACK (prefs_pattern_option_changed), file_key);
+    /* The gpointer cast is to prevent -Wdiscarded-quantifiers from
+       producing a warning. This is safe as the string is treated as
+       const gchar* in the callback. */
+    g_signal_connect (path_option, "changed",
+                      G_CALLBACK (prefs_pattern_option_changed),
+                      (gpointer) path_key);
+    populate_pattern_combo (GTK_COMBO_BOX (file_option), (gpointer) file_patterns);
+    /* The gpointer cast is to prevent -Wdiscarded-quantifiers from
+       producing a warning. This is safe as the string is treated as
+       const gchar* in the callback. */
+    g_signal_connect (file_option, "changed",
+                      G_CALLBACK (prefs_pattern_option_changed),
+                      (gpointer) file_key);
     populate_profile_combo (GTK_COMBO_BOX (profile_option));
     g_signal_connect (profile_option, "changed", G_CALLBACK (prefs_profile_changed), NULL);
 
@@ -424,7 +436,7 @@ void show_preferences_dialog ()
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_STRIP,
                       (GCallback)strip_changed_cb, NULL);
 
-    g_signal_connect (extractor, "notify::profile", pattern_label_update, NULL);
+    g_signal_connect (sj_extractor, "notify::profile", pattern_label_update, NULL);
 
     baseuri_changed_cb (sj_settings, SJ_SETTINGS_BASEURI, NULL);
     settings_changed_cb (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, profile_option);
