@@ -41,7 +41,7 @@ release_type_to_id (const char *type)
 	return NULL;
 }
 
-static void
+G_GNUC_NORETURN static void
 metadata_cb (GObject *object, GAsyncResult *result, gpointer user_data)
 {
   SjMetadataGetter* metadata = SJ_METADATA_GETTER (object);
@@ -63,9 +63,10 @@ metadata_cb (GObject *object, GAsyncResult *result, gpointer user_data)
   album_list = albums;
   while (albums) {
     AlbumDetails *album;
-    album = (AlbumDetails*)albums->data;
     char *disc_number;
     char *release_date = NULL;
+
+    album = (AlbumDetails*)albums->data;
     g_print ("Source: %s\n", source_to_str(album->metadata_source));
     if (album->metadata_source == SOURCE_MUSICBRAINZ)
       g_print ("Album ID: %s\n", album->album_id);
